package com.muyu.market.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.market.domain.SysApitype;
import com.muyu.market.domain.SysFirm;
import com.muyu.market.service.ISysFirminfoService;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * firmListController
 *
 * @author 2112A
 * @date 2024-08-25
 */
@RestController
@RequestMapping("/firminfo")
public class SysFirminfoController extends BaseController
{
    @Autowired
    private ISysFirminfoService sysFirminfoService;

    @RequiresPermissions("firminfo:firminfo:upd")
    @PostMapping("/upd/{firmScore}")
    public Result upd(@PathVariable(value = "firmScore") Double firmScore) {
        Long adminsid = SecurityUtils.getUserId();
        SysFirm sysFirm = sysFirminfoService.selectSysFirminfoByAdminsid(adminsid);
        if(sysFirm.getFirmScore()<firmScore){
            return Result.error("余额不足");
        }
        return Result.success(sysFirminfoService.upd(adminsid, firmScore));
    }

    /**
     * 查询firmList列表
     */

    @RequiresPermissions("firminfo:firminfo:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysFirm>> list(SysFirm sysFirm)
    {
        startPage();
        List<SysFirm> list = sysFirminfoService.selectSysFirminfoList(sysFirm);
        return getDataTable(list);
    }

    @RequiresPermissions("firminfo:firminfo:query")
    @GetMapping(value = "/query")
    public Result getInfo()
    {
        Long adminsid = SecurityUtils.getUserId();
        return success(sysFirminfoService.selectSysFirminfoByAdminsid(adminsid));
    }

    @RequiresPermissions("firminfo:firminfo:add")
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody SysFirm sysFirminfo)
    {
        Long adminsid = SecurityUtils.getUserId();
        if (sysFirminfoService.selectSysFirminfoByAdminsid(adminsid)!=null) {
            return error("新增 firmList '" + sysFirminfo + "'失败，firmList已存在");
        }
        LocalDateTime now = LocalDateTime.now();

        // 假设我们使用系统默认时区
        ZoneId zoneId = ZoneId.systemDefault();

        // 将LocalDateTime转换为ZonedDateTime（添加了时区信息）
        ZonedDateTime zdt = now.atZone(zoneId);

        // 将ZonedDateTime转换为Instant（UTC时间线上的点）
        Instant instant = zdt.toInstant();

        // 将Instant转换为Date
        Date date = Date.from(instant);
        sysFirminfo.setFirmTime(date);
        sysFirminfo.setAdminsid(adminsid);
        sysFirminfo.setFirmScore(0.0);
        return toAjax(sysFirminfoService.save(sysFirminfo));
    }

    /**
     * 修改firmList
     */
    @RequiresPermissions("firminfo:firminfo:edit")
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody SysFirm sysFirminfo)
    {
        if (!sysFirminfoService.checkIdUnique(sysFirminfo)) {
            return error("修改 firmList '" + sysFirminfo + "'失败，firmList不存在");
        }
        return toAjax(sysFirminfoService.updateById(sysFirminfo));
    }

}
